// Copyright 2019 Josh Liburdi and Google Inc. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
syntax = "proto3";
package steno;

service Stenographer {
  rpc RetrievePcap(PcapRequest) returns (stream PcapResponse) {}
}

message PcapRequest {
  string uid = 1;
  int64 chunk_size = 2;
  int64 max_size = 3;
  string query = 4;
}

message PcapResponse {
  string uid = 1;
  bytes pcap = 2;
}
